package App::MakeWorld::Interpolate;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use POSIX qw[];
use App::MakeWorld::Global;

use String::Interpolate::Shell qw[ strinterp ];

use base qw[ Exporter ];

our @EXPORT = qw[
  interpolate
  interpolate_vars
];

our @EXPORT_OK = qw[
  InterpolateVars
];




# various variables that may be interpolated
our %InterpolateVars;

INIT {
    @InterpolateVars{
        qw(uname_sysname
          uname_nodename
          uname_release
          uname_version
          uname_machine)
      }
      = POSIX::uname();
}


sub interpolate {
    my ( $text, @vars ) = @_;


    return _interpolate( $text, interpolate_vars( @vars ) );
}

sub interpolate_vars {

    my ( @vars ) = @_;

    my %var = (
        # Interpolate command line option values
        builddir    => $Opt->builddir,
        cache       => $Opt->cache,
        exec_prefix => $Opt->exec_prefix,
        prefix      => $Opt->prefix,
        make_cmd    => $Opt->make_cmd,

        ( map { %{$_} } @vars ),
        %InterpolateVars,
        %ENV
    );

    return \%var;
}


sub _interpolate {

    my ( $text, $var ) = @_;

    if ( 'HASH' eq ref $text ) {
        while ( my ( $key, $val ) = each %$text ) {
            $text->{$key} = _interpolate( $val, $var );
        }
    }

    elsif ( 'ARRAY' eq ref $text ) {
        $text = [ map { _interpolate( $_, $var ) } @{$text} ];
    }

    else {
        $text = strinterp( $text, $var, { undef_value => 'ignore' } );
    }


    return $text;
}



1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Interpolate

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
