package App::MakeWorld::Mogrify::Exec;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use App::MakeWorld::Utils qw[ find_exe ];
use App::MakeWorld::Check qw[ check ];
use App::MakeWorld::Run;
use App::MakeWorld::Log;

use namespace::clean;

################################################################################
# execute a command

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
            exe  => { required => 1 },
            arg  => { default  => [] },
            hook => { required => $need_hook },
        },
        $opts
    );
}

sub mogrify {
    my ( $class, $pkg, $opt ) = @_;

    my $guard = log_pfx( '<exec>' );

    my $arg  = $opt->{arg};
    my $exe  = $opt->{exe};
    my $file = eval { find_exe( $exe ) };

    unless ( $file ) {
        return if $opt->{optional};
        log_error "$exe: non-existent or non-executable file\n";
    }

    my @cmd = ( $file, $arg );

    log_info( @cmd );

    run( @cmd )
      or log_fatal( "error running $exe\n" );

    return;
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Mogrify::Exec

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
