package App::MakeWorld::Mogrify::MkPath;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use App::MakeWorld::Global;
use App::MakeWorld::Check qw[ check ];
use App::MakeWorld::Log;

use namespace::clean;

sub verify {

    my ( $class, $opts, $need_hook ) = @_;

    return check( {
            arg  => { required => 1, default => [] },
            hook => { required => $need_hook },
        },
        $opts
    );
}


sub mogrify {
    require File::Path;

    my ( $class, $pkg, $opts ) = @_;

    my $guard = log_pfx( '<mkpath>' );

    log_info( $opts->{arg} );

    my $errors;
    File::Path::make_path( @{ $opts->{arg} }, { error => \$errors } );

    log_fatal( map { @_ = %$_; "$_->[0]: $_->[1]\n" } @$errors )
      if @$errors;

    return;
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Mogrify::MkPath

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
