package App::MakeWorld::Package::AutoConf;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use base 'App::MakeWorld::Package';

use App::MakeWorld::Global;
use App::MakeWorld::Run;

use namespace::clean;

sub matches_contents { -f 'configure'; }

sub configure {
    my $self = shift;

    $self->SUPER::configure && return;

    my $config_args = $self->{option}{configure}{arg};

    # just in case
    local %ENV = %ENV;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'configure' || $Opt->dryrun ) {
        my @args = '--prefix=' . $Opt->prefix;

        push @args, '--exec_prefix=' . $Opt->exec_prefix;

        push @args, '--cache=' . $Opt->cache if $self->option->{cache};
        push @args, $config_args             if $config_args;

        run( './configure', @args )
          or $self->_croak( "error configuring package\n" );
    }
}

sub build {
    my $self = shift;

    $self->SUPER::build && return;

    my @cmd = ( $Opt->make_cmd );

    push @cmd, "LIBTOOL=" . $self->{option}{libtool}
      if exists $self->{option}{libtool};

    push @cmd, ( $self->{option}{build}{arg} || () );

    run( @cmd )
      or $self->_croak( "error building package\n" );
}

sub test {
    my $self = shift;

    $self->SUPER::test && return;

    my @cmd = ( $Opt->make_cmd, 'check' );

    push @cmd, "LIBTOOL=" . $self->{option}{libtool}
      if exists $self->{option}{libtool};

    push @cmd, ( $self->{option}{test}{arg} || () );

    run( @cmd )
      or $self->_croak( "error testing package\n" );
}


sub install {
    my $self = shift;

    $self->SUPER::install && return;

    my @cmd = ( $Opt->make_cmd, 'install' );

    push @cmd, "LIBTOOL=" . $self->{option}{libtool}
      if exists $self->{option}{libtool};

    push @cmd, ( $self->{option}{install}{arg} || () );

    run( @cmd )
      or $self->_croak( "error installing package\n" );
}


1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Package::AutoConf

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
