package App::MakeWorld::Package::PerlModule;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use base 'App::MakeWorld::Package';

use File::Spec::Functions qw/ catdir /;

use App::MakeWorld::Global;
use App::MakeWorld::Run;

use namespace::clean;

sub matches_contents { -f 'Makefile.PL'; }


sub configure {
    my $self = shift;

    $self->SUPER::configure && return;

    # check for configure file. if its a dryrun, it's probable that the
    # source hasn't been unarchived and we won't see the configure file.
    # just assume its there. can't hurt!
    if ( -f 'Makefile.PL' || $Opt->dryrun ) {
        my @args;

        if ( $Opt->install_perl eq 'site' ) {
            @args = ( 'INSTALLDIRs=site' )
        }

        ## no critic (ProhibitStringyEval)
        elsif ( eval 'use ExtUtils::MakeMaker 6.31; 1;' ) {
            @args = ( 'INSTALL_BASE=' . $Opt->prefix );
        }

        else {
            require Config;

            @args = map { $_->[0] . '=' . catdir( @{ $_->[1] } ) }
              [ INSTALLDIRS => 'perl' ],
              [ INSTALLARCHLIB =>
                  [ $Opt->prefix, qw( lib perl5 ), $Config::Config{archname} ]
              ],
              [ INSTALLPRIVLIB => [ $Opt->prefix, qw( lib perl5 ) ] ],
              [ INSTALLBIN     => [ $Opt->prefix, 'bin' ] ],
              [ INSTALLSCRIPT  => [ $Opt->prefix, 'bin' ] ],
              [ INSTALLMAN1DIR => [ $Opt->prefix, qw( man man1) ] ],
              [ INSTALLMAN3DIR => [ $Opt->prefix, qw( man man3) ] ];
        }


        # Since we're not doing dependency resolution for Perl modules
        # (we're not running a cpan client), a missing dependency
        # is a failure -- the module should have been explicitly
        # installed as part of this build prior to it being required.
        # Supposedly a module's tests should guard against this (e.g.
        # tests should fail if a dependency isn't present), but we
        # can't trust that that will happen.
        push @args, 'PREREQ_FATAL=1';

        push @args, $self->{option}{configure}{arg};

        run( qw( perl Makefile.PL), @args )
          or $self->_croak( "error configuring package\n" );
    }
}

sub build {
    my $self = shift;

    $self->SUPER::build && return;

    my @cmd = ( $Opt->make_cmd );

    push @cmd, $self->{option}{build}{arg};

    run( @cmd )
      or die( "error building package\n" );
}

sub test {
    my $self = shift;

    $self->SUPER::test && return;

    run( $Opt->make_cmd, 'test' )
      or die( "error testing package\n" );
}


sub install {
    my $self = shift;

    $self->SUPER::install && return;

    run( $Opt->make_cmd, 'install' )
      or die( "error installing package\n" );
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Package::PerlModule

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
