package App::MakeWorld::Package::Unknown;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use base 'App::MakeWorld::Package';

use App::MakeWorld::Global;

use namespace::clean;

sub new {
    my ( $package, $self ) = @_;

    return bless $self, $package;
}

sub configure {
    my $self = shift;

    $self->SUPER::configure && return;

    $self->_croak( "internal error: illegal call to ", __PACKAGE__, "::configure\n" )
      unless $Opt->dryrun;

    if ( defined $self->{option}{configure}{arg} ) {
        print STDOUT "configuring with arguments ",
          join( ' ', @{ $self->{option}{configure}{arg} } ), "\n";
    }
    else {
        print STDOUT "configuring\n";
    }
}

sub build {
    my $self = shift;

    $self->SUPER::build && return;

    $self->_croak( "internal error: illegal call to ", __PACKAGE__, "::build\n" )
      unless $Opt->dryrun;

    if ( defined $self->{option}{build}{arg} ) {
        print STDOUT "building with arguments ",
          join( ' ', @{ $self->{option}{build}{arg} } ), "\n";
    }
    else {
        print STDOUT "building\n";
    }
}

sub test {
    my $self = shift;

    $self->SUPER::test && return;

    $self->_croak( "internal error: illegal call to ", __PACKAGE__, "::test\n" )
      unless $Opt->dryrun;

    if ( defined $self->{option}{test}{arg} ) {
        print STDOUT "testing with arguments ",
          join( ' ', @{ $self->{option}{test}{arg} } ), "\n";
    }
    else {
        print STDOUT "testing\n";
    }
}


sub install {
    my $self = shift;

    $self->SUPER::install && return;

    $self->_croak( "internal error: illegal call to ", __PACKAGE__, "::install\n" )
      unless $Opt->dryrun;

    if ( defined $self->{option}{install}{arg} ) {
        print STDOUT "installing with arguments ",
          join( ' ', @{ $self->{option}{install}{arg} } ), "\n";
    }
    else {
        print STDOUT "installing\n";
    }
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Package::Unknown

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
