package App::MakeWorld::Utils;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use File::Spec::Functions qw[ catfile splitpath ];

use base 'Exporter';

use Module::Pluggable require => 1;
use Module::Load qw[ load ];
use App::MakeWorld::Global;

our @EXPORT_OK = qw[
  find_exe
  find_plugins
];


sub find_exe {
    my ( $exe ) = @_;

    my $dirs = ( splitpath( $exe ) )[1];
    my $file;

    # if a leading path was specified, use that directly
    if ( $dirs ne '' ) {
        $file = $exe if -f $exe && -x _;
    }

    # not absolute; find it
    else {
        ( $file ) = grep { -f $_ && -x _ }
          map { glob( catfile( $_, $exe ) ) } @{ $Opt->srcdir },
          split( ':', $ENV{PATH} ), '.';
    }

    die( "unable to find executable command: $exe \n" )
      unless $file;

    return $file;
}



sub find_plugins {

    my ( $pkg, $plugins, $map ) = @_;

    __PACKAGE__->search_path( new => $pkg );

    @{$plugins} = __PACKAGE__->plugins();
    %{$map}     = map {
        my $module = $_;
        $module =~ s/^.*:://;
        ( lc( $module ) => $_ )
    } @{$plugins};

    return;
}


1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::Utils

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
