package App::MakeWorld::VarStack;

use strict;
use warnings;

our $VERSION = 'v2.5.9';

use Storable ();

use App::MakeWorld::Log;

use namespace::clean;

my @Stack;

my $id = 0;


sub new {

    my ( $obj ) = @_;

    my $class = ref $obj || $obj;

    my $self = bless( ( ref $obj ? Storable::dclone( $obj ) : { var => {} } ), $class );

    $self->{_parent} = $obj
      if ref $obj;

    push @Stack, $self;

    return $self;
}

sub DESTROY {

    pop @Stack;

}

sub vars { return $_[0]->{var} }

sub value { return $_[0]->{var}{ $_[1] } }

sub exists { CORE::exists $_[0]->{var}{ $_[1] } }

sub set {

    my ( $self, %vars ) = @_;

    my ( $key, $val );
    $self->{var}{$key} = $val while ( $key, $val ) = each %vars;

    return $self;
}

sub dump {

    my ( $self, @vars ) = @_;

    @vars = keys %{ $self->{var} } unless @vars;

    log_debug(
        "$_: " . ( $self->exists( $_ ) ? $self->value( $_ ) : 'undef' ) . "\n" )
      foreach @vars;

    return;
}

sub parent {

    die( "internal error: no stack parent\n" )
      if ( @_ == 1 || !$_[-1] ) && !exists $_[0]->{_parent};

    return $_[0]->{_parent};
}

1;

__END__

=pod

=for :stopwords Diab Jerius Smithsonian Astrophysical Observatory

=head1 NAME

App::MakeWorld::VarStack

=head1 VERSION

version v2.5.9

=head1 SEE ALSO

Please see those modules/websites for more information related to this module.

=over 4

=item *

L<bin::make-world|bin::make-world>

=back

=head1 AUTHOR

Diab Jerius <djerius@cfa.harvard.edu>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Smithsonian Astrophysical Observatory.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=cut
